@@ -135,11 +135,13 @@ def read(fp, as_version, **kwargs):
     """
 
     try:
-        return reads(fp.read(), as_version, **kwargs)
+        buf = fp.read()
     except AttributeError:
         with io.open(fp, encoding='utf-8') as f:
             return reads(f.read(), as_version, **kwargs)
 
+    return reads(buf, as_version, **kwargs)
+
 
 def write(nb, fp, version=NO_CONVERT, **kwargs):
     """Write a notebook to a file in a given nbformat version.
